==> apracjs-13.1.29.tgz: package/lib/scripts/dataSource/dbPagerDataSource.js <==
﻿/*!
 * PagerDataSource
 * Copyright(c) 2017 by wssf
 * 2017-06-09
 */

'use strict'
var PagerDataSource = require('./pagerDataSource.js');
var debug = require('debug')('aprac:DbPagerDataSource');
var utils = require('../../common/utils.js');
var config = require('../../config.js').apracConfig;
var dataHelper = require('./dataHelper.js');
var DbHelper = require('../../database/dbHelper.js');

class DbPagerDataSource extends PagerDataSource {
  constructor(connectionString) {
    super();
    this.connectionString = connectionString;
    this.fieldNameIgnoreCase = false;
    this.useMemorySort = true;
  }

  createDbHelper() {
    var dbHelper = new DbHelper(this.connectionString);
    dbHelper.isSelecting = true; // 正在执行的是查询
    return dbHelper;
  }

  getQueryData() {
    var queryCache = this.getQueryCache();
    if (!queryCache) {
      var dbHelper = this.createDbHelper();
      queryCache = this.internalDoQuery(dbHelper);
      if (typeof this.afterLoad == "function") {
        queryCache = this.afterLoad(dbHelper, queryCache);
      }
      this.cacheDataTable(queryCache);
    }
    return queryCache;
  }

  getQueryCache() {
    return this._queryCache;
  }

  cacheDataTable(list) {
    this._queryCache = list;
  }

  internalDoQuery(dbHelper) {
    return this.doQuery(dbHelper);
  }

  doQuery() {
    // 子类实现
  }

  setOrders(orders) {
    super.setOrders(orders);
    var list = this.getQueryData();
    // to do
  }

  setFilter(filter) {
    super.setFilter(filter);
    if (filter == null) return;

    var list = this.getQueryData(); // 保证有数据       
    if (list.length == 0) return; // 没有数据的情况

    try {
      // to do
    }
    catch (ex) {
      throw new Error(utils.format("设置过滤失败，“{0}”", ex.message));
    }
  }

  invalidateCache() {
    this._queryCache = null;
  }

  getItemCount() {
    return this.getQueryData().length;
  }

  getItemList(first, count) {
    var list = this.getQueryData();
    if (!this._serverBinding) {
      return dataHelper.getListByIndex(list, first, count); // count < 0 说明取全部
    }

    if (!this._showAll) {
      if (count < 0) {
        count = list.length;
      }
      return dataHelper.getListByIndex(list, first, count);
    } else {
      return list;
    }
  }
}

module.exports = DbPagerDataSource;

==> apracjs-18.1.2.tgz: package/lib/scripts/dataSource/dbPagerDataSource.js <==
﻿/*!
 * PagerDataSource
 * Copyright(c) 2017 by wssf
 * 2017-06-09
 */

'use strict'
var PagerDataSource = require('./pagerDataSource.js');
var debug = require('debug')('aprac:DbPagerDataSource');
var utils = require('../../common/utils.js');
var config = require('../../config.js').apracConfig;
var dataHelper = require('./dataHelper.js');
var DbHelper = require('../../database/dbHelper.js');

class DbPagerDataSource extends PagerDataSource {
  constructor(connectionString) {
    super();
    this.connectionString = connectionString;
    this.fieldNameIgnoreCase = false;
    this.useMemorySort = true;
  }

  createDbHelper() {
    var dbHelper = new DbHelper(this.connectionString);
    dbHelper.isSelecting = true; // 正在执行的是查询
    return dbHelper;
  }

  getQueryData() {
    var queryCache = this.getQueryCache();
    if (!queryCache) {
      var dbHelper = this.createDbHelper();
      queryCache = this.internalDoQuery(dbHelper);
      if (typeof this.afterLoad == "function") {
        queryCache = this.afterLoad(dbHelper, queryCache);
      }
      this.cacheDataTable(queryCache);
    }
    return queryCache;
  }

  getQueryCache() {
    return this._queryCache;
  }

  cacheDataTable(list) {
    this._queryCache = list;
  }

  internalDoQuery(dbHelper) {
    return this.doQuery(dbHelper);
  }

  doQuery() {
    // 子类实现
  }

  setOrders(orders) {
    super.setOrders(orders);
    var list = this.getQueryData();
    // to do
  }

  setFilter(filter) {
    super.setFilter(filter);
    if (filter == null) return;

    var list = this.getQueryData(); // 保证有数据       
    if (list.length == 0) return; // 没有数据的情况

    try {
      // to do
    }
    catch (ex) {
      throw new Error(utils.format("设置过滤失败，“{0}”", ex.message));
    }
  }

  invalidateCache() {
    this._queryCache = null;
  }

  getItemCount() {
    return this.getQueryData().length;
  }

  getItemList(first, count) {
    var _this = this;
    return async (cb) => {
      try {
        var list = _this.getQueryData();
        if (!_this._serverBinding) {
          return cb(dataHelper.getListByIndex(list, first, count)); // count < 0 说明取全部
        }

        if (!_this._showAll) {
          if (count < 0) {
            count = list.length;
          }
          cb(dataHelper.getListByIndex(list, first, count));
        } else {
          cb(list);
        }
      }
      catch (ex) {
        db.close();
        cb(null, ex);
      }
    }
  }
}

module.exports = DbPagerDataSource;
